<?php 

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function sixart_widgets_init() {

    $footer_style_2_switch = get_theme_mod( 'footer_style_2_switch', true );
    $footer_style_3_switch = get_theme_mod( 'footer_style_3_switch', true );

    /**
     * blog sidebar
     */
    register_sidebar( [
        'name'          => esc_html__( 'Blog Sidebar', 'sixart' ),
        'id'            => 'blog-sidebar',
        'before_widget' => '<div id="%1$s" class="sidebar__widget mb-40 %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="sidebar__widget-title">',
        'after_title'   => '</h3>',
    ] );


    $footer_widgets = get_theme_mod( 'footer_widget_number', 4 );

    // footer default
    for ( $num = 1; $num <= $footer_widgets; $num++ ) {
        register_sidebar( [
            'name'          => sprintf( esc_html__( 'Footer %1$s', 'sixart' ), $num ),
            'id'            => 'footer-' . $num,
            'description'   => sprintf( esc_html__( 'Footer %1$s', 'sixart' ), $num ),
            'before_widget' => '<div id="%1$s" class="footer__widget tp-footer-widget footer-col-'.$num.' mb-30 %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<div class="tp-footer-widget__title"><h4 class="tp-footer-title">',
            'after_title'   => '</h4></div>',
        ] );
    }

    // footer 2
    if ( $footer_style_2_switch ) {
        for ( $num = 1; $num <= $footer_widgets + 1 ; $num++ ) {

            register_sidebar( [
                'name'          => sprintf( esc_html__( 'Footer Style 2 : %1$s', 'sixart' ), $num ),
                'id'            => 'footer-2-' . $num,
                'description'   => sprintf( esc_html__( 'Footer Style 2 : %1$s', 'sixart' ), $num ),
                'before_widget' => '<div id="%1$s" class="footer__widget footer__widget-2 tp-footer-widget z-index-3 footer-col-2-'.$num.' mb-10 %2$s">',
                'after_widget'  => '</div>',
                'before_title'  => '<div class="tp-footer-widget__title"><h4 class="tp-footer-title">',
                'after_title'   => '</h4></div>',
            ] );
        }
    }    

    // footer 3
    if ( $footer_style_3_switch ) {
        for ( $num = 1; $num <= $footer_widgets + 1; $num++ ) {
            register_sidebar( [
                'name'          => sprintf( esc_html__( 'Footer Style 3 : %1$s', 'sixart' ), $num ),
                'id'            => 'footer-3-' . $num,
                'description'   => sprintf( esc_html__( 'Footer Style 3 : %1$s', 'sixart' ), $num ),
                'before_widget' => '<div id="%1$s" class="footer__widget tp-footer-widget z-index-3 footer-col-3-'.$num.' %2$s">',
                'after_widget'  => '</div>',
                'before_title'  => '<div class="tp-footer-widget__title"><h4 class="tp-footer-title">',
                'after_title'   => '</h4></div>',
            ] );
        }
    }    

}
add_action( 'widgets_init', 'sixart_widgets_init' );